summaryrefslogtreecommitdiffstats
path: root/libfdisk/src/alignment.c
diff options
context:
space:
mode:
authorSebastian Rasmussen2016-05-29 23:11:53 +0200
committerSebastian Rasmussen2016-05-31 23:40:21 +0200
commit9e93004171eb0c4c288051b2d7bb37f97a0ae430 (patch)
tree369493906bb3c1c6f2554609c737ada0230f4b2e /libfdisk/src/alignment.c
parentdocs: Fix various typos (diff)
downloadkernel-qcow2-util-linux-9e93004171eb0c4c288051b2d7bb37f97a0ae430.tar.gz
kernel-qcow2-util-linux-9e93004171eb0c4c288051b2d7bb37f97a0ae430.tar.xz
kernel-qcow2-util-linux-9e93004171eb0c4c288051b2d7bb37f97a0ae430.zip
misc: Fix various typos
Fix various typos in error messages, warnings, debug strings, comments and names of static functions. Signed-off-by: Sebastian Rasmussen <sebras@gmail.com>
Diffstat (limited to 'libfdisk/src/alignment.c')
-rw-r--r--libfdisk/src/alignment.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/libfdisk/src/alignment.c b/libfdisk/src/alignment.c
index aa082e189..58acefb89 100644
--- a/libfdisk/src/alignment.c
+++ b/libfdisk/src/alignment.c
@@ -215,7 +215,7 @@ static void recount_geometry(struct fdisk_context *cxt)
*
* The difference between fdisk_override_geometry() and fdisk_save_user_geometry()
* is that saved user geometry is persistent setting and it's applied always
* when device is assigned to the context or device properties are reseted.
*
* Returns: 0 on success, < 0 on error.
*/
@@ -287,7 +287,7 @@ int fdisk_save_user_geometry(struct fdisk_context *cxt,
* fdisk_save_user_sector_size:
* @cxt: context
* @phy: physical sector size
- * @log: logicla sector size
+ * @log: logical sector size
*
* Save user defined sector sizes to use it for partitioning.
*
@@ -331,7 +331,7 @@ int fdisk_apply_user_device_properties(struct fdisk_context *cxt)
if (!cxt)
return -EINVAL;
- DBG(CXT, ul_debugobj(cxt, "appling user device properties"));
+ DBG(CXT, ul_debugobj(cxt, "applying user device properties"));
if (cxt->user_pyh_sector)
cxt->phy_sector_size = cxt->user_pyh_sector;
@@ -403,7 +403,7 @@ int fdisk_reset_device_properties(struct fdisk_context *cxt)
if (!cxt)
return -EINVAL;
- DBG(CXT, ul_debugobj(cxt, "*** reseting device properties"));
+ DBG(CXT, ul_debugobj(cxt, "*** resetting device properties"));
fdisk_zeroize_device_properties(cxt);
fdisk_discover_topology(cxt);
@@ -546,7 +546,7 @@ static fdisk_sector_t topology_get_first_lba(struct fdisk_context *cxt)
* a2) alignment offset
* a1) or physical sector (minimal_io_size, aka "grain")
*
- * b) or default to 1MiB (2048 sectrors, Windows Vista default)
+ * b) or default to 1MiB (2048 sectors, Windows Vista default)
*
* c) or for very small devices use 1 phy.sector
*/
@@ -608,7 +608,7 @@ int fdisk_reset_alignment(struct fdisk_context *cxt)
if (!cxt)
return -EINVAL;
- DBG(CXT, ul_debugobj(cxt, "reseting alignment..."));
+ DBG(CXT, ul_debugobj(cxt, "resetting alignment..."));
/* default */
cxt->grain = topology_get_grain(cxt);
@@ -619,7 +619,7 @@ int fdisk_reset_alignment(struct fdisk_context *cxt)
if (cxt->label && cxt->label->op->reset_alignment)
rc = cxt->label->op->reset_alignment(cxt);
- DBG(CXT, ul_debugobj(cxt, "alignment reseted to: "
+ DBG(CXT, ul_debugobj(cxt, "alignment reset to: "
"first LBA=%ju, last LBA=%ju, grain=%lu [rc=%d]",
(uintmax_t) cxt->first_lba, (uintmax_t) cxt->last_lba,
cxt->grain, rc));
@@ -215,7 +215,7 @@ static void recount_geometry(struct fdisk_context *cxt)
* The difference between fdisk_override_geometry() and fdisk_save_user_geometry()
* is that saved user geometry is persistent setting and it's applied always
- * when device is assigned to the context or device properties are reseted.
+ * when device is assigned to the context or device properties are reset.
*
* Returns: 0 on success, < 0 on error.